<?php
/**
 * @package		Joomla.Plugin
 * @subpackage	Content.geshi
 * @copyright	Copyright (C) 2005 - 2012 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access.
defined('_JEXEC') or die;

class plgContentQRCodesLocal extends JPlugin
{
	/**
	 * @param	string	The context of the content being passed to the plugin.
	 * @param	object	The article object.  Note $article->text is also available
	 * @param	object	The article params
	 * @param	int		The 'page' number
	 */
	public function onContentPrepare($context, &$article, &$params, $page)
	{
		// Simple performance check to determine whether bot should process further.
		if (JString::strpos($article->text, 'qrcodeslocal') === false) {
			return true;
		}

		// Define the regular expression for the bot.
		$regex = "#{qrcodeslocal}(.*?){\/qrcodeslocal}#is";

		// find all instances of plugin and put in $matches
		preg_match_all( $regex, $article->text, $matches );

		// Number of plugins
		$count = count( $matches[0] );

		// plugin only processes if there are any instances of the plugin in the text
		if ( $count ) {
			// Get plugin parameters
			//$style	= $pluginParams->def( 'style', -2 );

			$this->QRCodesLocalCreateImage( $article, $matches, $count, $regex );
		}
		return true;
	}

	/**
	 * Replace the matched tags.
	 *
	 * @param	array	article object
	 * @param	array	An array of matches
	 * @param	int		count of matches
	 * @param	string	regex to match
	 * @return	none
	 */

	protected function QRCodesLocalCreateImage( &$row, &$matches, $count, $regex ) {

		for ( $i=0; $i < $count; $i++ )
		{
			$text_to_replace = str_replace( '{qrcodeslocal}', '', $matches[0][$i] );
			$text_to_replace = str_replace( '{/qrcodeslocal}', '', $text_to_replace );
			$row->text = str_replace( $matches[0][$i], $this->getQRText($text_to_replace,$this->params), $row->text );
		}
	}

	/**
	 * Create the <img> tag and actual file from the text.
	 *
	 * @param	string	text in the tags
	 * @param	array	plugins parameters
	 * @return	none
	 */
	protected function getQRText($picture_text, $botParams) {
		require_once(JPATH_SITE.DS.'modules'.DS.'mod_qrcodes_local'.DS.'tmpl'.DS.'qr_img.php');

		$picture_url = $picture_text;
		$SERVER_PATH_FOLDER = JPATH_CACHE.DS."qrcodes_local".DS;
		$CACHE_FOLDER = "cache".DS."qrcodes_local".DS;
		$folder_permissions = (int) $botParams->get( 'folder_permissions', 0755 );
		$file_permissions = (int) $botParams->get( 'file_permissions', 0644 );
		$expires_time = (int) $botParams->get( 'expires_time', 10080 );
		$expires_period = $botParams->get( 'expires_period', 'minutes' );

		// CREATE cache folder with write perms, the @ means it won't show errors if cache folder exists already
		@mkdir($SERVER_PATH_FOLDER,0755);

		// picture_text - NEED to REPLACE certain characters for file system
		// $picture_text = str_replace( array( " ", "/", ".", "?", "&", "=", "%", ",", "[", "]", "<", ">", "*", "!", "|", "\"", "'" ), "-", $picture_text );
		$picture_url = preg_replace("/[^a-z0-9_-s.]/i","-",$picture_url); 
		// CHECK IF QR CODE FOR THIS URL ALREADY EXISTS
		if (!file_exists($SERVER_PATH_FOLDER.$picture_url.".png") ) {
			// IF NOT CREATE IT
			// using function create($name, $url, $output, $type, $size, $data, $correct, $version)
			qrcode_image::create( $picture_url, $picture_text, $CACHE_FOLDER, "", 4, $picture_text, 'M', "" );
			chmod($SERVER_PATH_FOLDER.$picture_url.".png", $file_permissions);
		}
		// CREATE AN EXPIRES FILE FOR THE CACHED FILE (IF ONE DOESN'T EXIST) WITHOUT THE IF UPDATES AT EACH USE.
		//if (!file_exists($SERVER_PATH_FOLDER.$picture_text.".png_expire") ) {
			$date = new DateTime();
			$date->modify('+'.$expires_time.' '.$expires_period);
			file_put_contents($SERVER_PATH_FOLDER.$picture_url.".png_expire",$date->getTimestamp());
			chmod($SERVER_PATH_FOLDER.$picture_url.".png_expire", $file_permissions);
		//}
		$qr_code = '<img src="'.$CACHE_FOLDER.$picture_url.'.png" alt="QRCODE - '.$picture_text.'" />';

		return $qr_code;
	}
}
